UNIT uKomponente;
(* ******************************************************************** *)
(* K L A S S E : TKomponente                                            *)
(* -------------------------------------------------------------------- *)
(* Version     : 0.9                                                    *)
(* Autor       : Iatsenko viktor, Schulz Martin                         *)
(* Beschreibung: Die Klasse bildet die gemeinsamen Attrribute alle PC-  *)
(*               komponenten ab.                                        *)
(* Compiler    : Delphi 6.0                                             *)
(* Aenderungen : ----                                                   *)
(* ******************************************************************** *)

INTERFACE
// =======================================================================
USES Classes;   // import: TFilestream, read, write

type
  TKomponente = class(TObject)

    protected
    Hersteller  : string[20];
    Art         : string[15];
    Typ         : string[15];

   public
    constructor Create;                      virtual;
    procedure   Init;                        virtual;
    procedure   SetHersteller  (h: string);  virtual;
    procedure   SetArt         (a: string);  virtual;
    procedure   SetTyp         (t: string);  virtual;

    function GetHersteller       : string;         virtual;
    function GetArt              : string;         virtual;
    function GetTyp              : string;         virtual;

 //   function IstGleich (suchkomp : TKomponente) : boolean;  virtual;

    procedure InDateiSchreiben (var fs : TFilestream); virtual;
    procedure AusDateiLesen    (var fs : TFilestream); virtual;
  end;

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse    : Komponente
Bezugsklassen : ...........      import:


Methoden
--------

Create
  Auftrag: Ein neues Objekt erzeugen
  vorher : --
  nachher: Objekt ist vorhanden; alle Felder sind leer.

Init
  Auftrag: Objekte mit Anfangswerten neu initialisieren.
  vorher : Objekt ist vorhanden.
  nachher: Alle Felder sind leer.


Set...
  Auftrag: Attribut schreiben
  vorher : Objekt ist init.
  nachher: Attribut ist gesetzt

Get...
  Auftrag: Attribut aus dem Objekt lesen
  vorher : Person ist init.
  nachher: -

IstGleich (suchkomp : TKomponente)
  Auftrag: Attribute Typ, Art, Hersteller vergleichen ob vorhanden
  vorher : Attribut ist vorhanden
  nachher: IstGleich liefert True, wenn Typ, Art, Hersteller bereinstimmen

InDateiSchreiben (var fs : TFilestream)
  Auftrag: Attribut auf die Festplatte speichern
  vorher : fs ist geffnet
  nachher: Attribute sind an fs bergeben

AusDateiLesen (var fs : TFilestream)
  Auftrag: Attribute von der Festplatte laden
  vorher : fs ist geffnet
  nachher: Attribute sind an Objekt bergeben.
--------------------------------------------------------------------- *)


IMPLEMENTATION
// ====================================================================


constructor TKomponente.Create;
// --------------------------------------------------------------------
begin
inherited Create;
  Init;
end;


procedure TKomponente.Init;
// --------------------------------------------------------------------
begin
//inherited Init;
  Hersteller   := '';
  Art          := '';
  Typ          := '';
end;

procedure TKomponente.SetHersteller     (h: string);
// --------------------------------------------------------------------
begin
  Hersteller := h;
end;

procedure TKomponente.SetArt             (a: string);
// --------------------------------------------------------------------
begin
   Art := a;
end;

procedure TKomponente.SetTyp             (t : string);
// --------------------------------------------------------------------
begin
   Typ := t;
end;

function TKomponente.GetHersteller : string;
// --------------------------------------------------------------------
begin
   Result := Hersteller
end;

function TKomponente.GetArt  : string;
// --------------------------------------------------------------------
begin
   Result := Art
end;

function TKomponente.GetTyp     : string;
// --------------------------------------------------------------------
begin
   Result := Typ
end;

{
function TKomponente.IstGleich (suchkomp : TKomponente) : boolean;
// --------------------------------------------------------------------
begin
   result := false;
  if suchkomp.Typ = Typ
  then result := true
end;
}


procedure TKomponente.InDateiSchreiben (var fs : TFilestream);
// --------------------------------------------------------------------
begin
//    inherited InDateiSchreiben(Fs);
  Fs.Write( Hersteller, sizeof(Hersteller));
  Fs.Write( Art, sizeof(Art));
  Fs.Write( Typ, sizeof(Typ));
end;

procedure TKomponente.AusDateiLesen    (var fs : TFilestream);
// --------------------------------------------------------------------
begin
//    inherited AusDateiLesen(Fs);
  Fs.Read( Hersteller, sizeof(Hersteller));
  Fs.Read( Art, sizeof(Art));
  Fs.Read( Typ, sizeof(Typ));
end;


END. // -------- UNIT -------------
