UNIT uPc;

(* ******************************************************************** *)
(* K L A S S E : TTestKlasse                                                   *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.0                                                    *)
(* Autor       : Gregor Gerbsch OSZ-Handel I, 10997 Berlin                 *)
(*                                                                      *)
(* Beschreibung: bildet das Objekt TPc ab.                               *)
(*                                                                      *)
(* Compiler    : DELPHI 6.0                                             *)
(* Aenderung   : V. 1.0  05.DEZ-02                                      *)
(* ******************************************************************** *)

INTERFACE
(* ========================== Export ================================== *)
USES
  Classes,
//  uKomponente,
  uArbeitsspeicher,
  uProzessor,
  uMotherboard,
  uFestplatte,
  uGrafikkarte,
  uGehaeuse,
  uSoundkarte,
  uNetzwerkkarte;


type
   TPc= class (TObject)
      // private
      RaumNummer : string[15];
      PcNummer   : string[15];
      TagAnschaffung : string[15];
      Betriebssystem : string;
      Arbeitsspeicher :TArbeitsspeicher;
      Prozessor      :TProzessor;
      Motherboard    :TMotherboard;
      Festplatte     :TFestplatte;
      Grafikkarte    :TGrafikkarte;
      Gehaeuse       :TGehaeuse;
      Soundkarte     :TSoundkarte;
      Netzwerkkarte  :TNetzwerkkarte;
     public
      constructor Create;
      procedure Init;
      procedure SetRaumNummer (rn : string);
      procedure SetPcNummer (pcn : string);
      procedure SetTagAnschaffung (ta : string);
      procedure SetBetriebssystem (b : string);


      function  GetRaumNummer : string;
      function  GetPcNummer : string;
      function  GetTagAnschaffung : string;
      function  GetBetriebssystem : string;

			function  IstGleich (suchkomp : TPc) : boolean;  virtual;

      procedure InDateiSchreiben (var Fs : TFilestream);
      procedure AusDateiLesen  (var Fs : TFilestream);
   end; (* TPcKlasse*)

(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse     : -
Bezugsklassen  : TClasses - import: TFilestream, read,write


Methoden
--------

Create
  Auftrag: erstellt die Klasse
  vorher : -
  nachher: Klasse wurde erstellt

Init
  Auftrag: alle Attribute werden auf 0 gesetzt
  vorher : -
  nachher: -

Set...
  Auftrag: Attribut schreiben
  vorher :
  nachher:

Get...
  Auftrag: Attribut aus dem Objekt lesen
  vorher :
  nachher:

IstGleich (suchtk : TPcKlasse) : boolean
  Anfrage: prfen, ob TPc gleich suchtk ist.
  vorher :
  nachher:

InDateiSchreiben (var fs : TFilestream)
  Auftrag: Attribute auf die Festplatte speichern
  vorher : fs ist geffnet
  nachher: Attribute sind an fs uebergeben


AusDateiLesen (var fs : TFilestream)
  Auftrag: Attribute von der Festplatte laden
  vorher : fs ist geffnet
  nachher: Attribute sind an Pc uebergeben

----------------------------------------------------------------------- *)

IMPLEMENTATION
(* ==================================================================== *)

constructor TPc.Create;
(* -------------------------------------------------------------------- *)
begin
  inherited Create;
  Arbeitsspeicher := TArbeitsspeicher.Create;
  Prozessor := TProzessor.Create;
  Motherboard := TMotherboard.Create;
  Festplatte := TFestplatte.Create;
  Grafikkarte := TGrafikkarte.Create;
  Gehaeuse := TGehaeuse.Create;
  Soundkarte := TSoundkarte.Create;
  Netzwerkkarte := TNetzwerkkarte.Create;
  Init;
end;


procedure TPc.Init;
(* -------------------------------------------------------------------- *)
begin

	RaumNummer      := '';
  PcNummer        := '';
  TagAnschaffung  := '';
  Betriebssystem  := '';

end;


procedure TPc.SetRaumNummer (rn : string);
(* -------------------------------------------------------------------- *)
begin
  RaumNummer := rn;
end;

procedure TPc.SetPcNummer (pcn : string);
(* -------------------------------------------------------------------- *)
begin
  PcNummer := pcn;
end;

procedure TPc.SetTagAnschaffung (ta : string);
(* -------------------------------------------------------------------- *)
begin
  TagAnschaffung := ta;
end;

procedure TPc.SetBetriebssystem (b : string);
(* -------------------------------------------------------------------- *)
begin
  Betriebssystem := b;
end;


function TPc.GetRaumNummer : string;
(* -------------------------------------------------------------------- *)
begin
  result := RaumNummer;
end;

function TPc.GetPcNummer : string;
(* -------------------------------------------------------------------- *)
begin
  result := PcNummer;
end;

function TPc.GetTagAnschaffung : string;
(* -------------------------------------------------------------------- *)
begin
  result := TagAnschaffung;
end;

function TPc.GetBetriebssystem : string;
(* -------------------------------------------------------------------- *)
begin
  result := Betriebssystem;
end;


function TPc.IstGleich (suchkomp : TPc) : boolean;
(* -------------------------------------------------------------------- *)
begin
  {result := false;
  if suchpers.Name = Name
  then result := true }

end;


procedure TPc.InDateiSchreiben (var Fs : TFilestream);
(* -------------------------------------------------------------------- *)
begin

  Arbeitsspeicher.InDateiSchreiben(Fs);
  Prozessor.InDateiSchreiben(Fs);
  Motherboard.InDateiSchreiben(Fs);
  Festplatte.InDateiSchreiben(Fs);
  Grafikkarte.InDateiSchreiben(Fs);
  Gehaeuse.InDateiSchreiben(Fs);
  Soundkarte.InDateiSchreiben(Fs);
  Netzwerkkarte.InDateiSchreiben(Fs);
  Fs.write( RaumNummer, sizeoF(RaumNummer));
  Fs.write( PcNummer, sizeoF(PcNummer));
  Fs.write( TagAnschaffung, sizeoF(TagAnschaffung));
  Fs.write( Betriebssystem, sizeoF(Betriebssystem));

end;


procedure TPc.AusDateiLesen (var Fs : TFilestream) ;
(* -------------------------------------------------------------------- *)
begin
  Arbeitsspeicher.AusDateiLesen(Fs);
  Prozessor.AusDateiLesen(Fs);
  Motherboard.AusDateiLesen(Fs);
  Festplatte.AusDateiLesen(Fs);
  Grafikkarte.AusDateiLesen(Fs);
  Gehaeuse.AusDateiLesen(Fs);
  Soundkarte.AusDateiLesen(Fs);
  Netzwerkkarte.AusDateiLesen(Fs);
  Fs.read( RaumNummer, sizeoF(RaumNummer));
  Fs.read( PcNummer, sizeoF(PcNummer));
  Fs.read( TagAnschaffung, sizeoF(TagAnschaffung));
  Fs.read( Betriebssystem, sizeoF(Betriebssystem));
end;



END.
