UNIT uPcListe;
(* ******************************************************************** *)
(*                                                                      *)
(* K L A S S E   : TPcListe                                           *)
(* -------------------------------------------------------------------- *)
(* Version       : 1.0                                                  *)
(* Autor         : Gregor Gerbsch OSZ-Handel I, 10997 Berlin               *)
(*                                                                      *)
(* Aufgabe       : Dyn. Liste zur Verwaltung der xxx-Objekte.           *)
(*                                                                      *)
(* Compiler      : Delphi 6.0                                           *)
(* Aenderung     : V. 1.0   - 05-DEZ-02                                 *)
(* ******************************************************************** *)

INTERFACE
(* ==================================================================== *)
USES  Classes,
      Sysutils,
      uDListe,
      uPc;


type
  TElement = TPc;

  TPcListe  = class (TListe)
                 public
                  function  SearchElement (suchElem : TElement) : TElement; reintroduce;
                  procedure Load (Dateiname : string); override;
                  procedure Store(Dateiname : string); override;
                 end;

(*  ----------------- B e s c h r e i b u n g -------------------------

Oberklasse     : TListe
Bezugsklassen  :
                 Classes - import: TFilstream, read, write
                 Sysutils        : Fileexists
Methoden
--------
SearchElement (suchElem : TElement) : TElement;
  Anfrage:
  vorher : -
  nachher:


Load (dateiname : string);
  Auftrag: Liste aus externer Datei laden. Wenn keine Datei existiert, dann neue
           Datei mit der Laenge 0 anlegen.
  vorher : Die Liste ist initialisiert.
  nachher: Die Liste ist in den Arbeitsspeicher geladen. Datei ist geschlossen.


Store (dateiname : string);
  Auftrag: Liste in externe Datei speichern
  vorher : -
  nachher: Die Liste ist gespeichert. Ist die Liste leer, wird nichts
          gespeichert. Datei ist geschlossen.

----------------------------------------------------------------------- *)


IMPLEMENTATION
(* ==================================================================== *)


function  TPcListe.SearchElement (suchElem : TElement) : TElement;
(* -------------------------------------------------------------------- *)
var gefunden : boolean;
Elem : TElement;
begin

begin
  Result := NIL;
  gefunden := false;

  while NOT (gefunden or Eolist) do
  begin
    Elem := GetElement;
    if Elem.IstGleich(suchElem)
    then
      begin
        gefunden := true;
        Result := Elem;
      end
    else inc(AktuellePos) // Next;
  end;
end;

end;


procedure TPcListe.Load (Dateiname : string);
(* -------------------------------------------------------------------- *)
var
    Elem  : TElement;
    Fs    : TFilestream;
    i,
    Anzahl: integer;

begin

  Anzahl := 0 ;
  if NOT FileExists(Dateiname)
  then Fs := TFilestream.Create(Dateiname, fmCreate)
  else Fs := TFilestream.Create(Dateiname, fmOpenRead);

  if Fs.Size > 0
  then
    begin
      Fs.Read(Anzahl, SizeOf(Listenlaenge));
      for i := 1 to Anzahl do
      begin
        elem := Telement.Create;
        Elem.AusDateiLesen(Fs);
        Append(Elem);
      end;
      AktuellePos := 0;
    end;
  Fs.Free;
end;


procedure TPcListe.Store(Dateiname : string);
(* -------------------------------------------------------------------- *)
var Elem  : TElement;
    Fs    : TFilestream;

begin
  DeleteFile(Dateiname);
  Fs := TFilestream.Create(Dateiname, fmCreate);

  if not IsEmpty
  then
  begin
    Fs.Write(Listenlaenge, SizeOf(Listenlaenge));
    First;
    while NOT EoList do
    begin
      Elem := GetElement;
      Elem.InDateiSchreiben (Fs);
      inc(AktuellePos); //Next;
    end;
  end;
  Fs.Free;
end;

END.
